@@ -6,8 +6,10 @@ extern "C" {
 #endif
 
 #include <cmark.h>
-#include <render.h>
-#include <buffer.h>
+
+struct cmark_renderer;
+struct cmark_html_renderer;
+struct cmark_chunk;
 
 /**
  * ## Extension Support
@@ -115,11 +117,9 @@ typedef struct delimiter {
   struct delimiter *next;
   cmark_node *inl_text;
   bufsize_t length;
-  int position;
   unsigned char delim_char;
   int can_open;
   int can_close;
-  int active;
 } delimiter;
 
 /**
@@ -229,7 +229,7 @@ typedef int (*cmark_contains_inlines_func) (cmark_syntax_extension *extension,
                                             cmark_node *node);
 
 typedef void (*cmark_common_render_func) (cmark_syntax_extension *extension,
-                                          cmark_renderer *renderer,
+                                          struct cmark_renderer *renderer,
                                           cmark_node *node,
                                           cmark_event_type ev_type,
                                           int options);
@@ -239,7 +239,7 @@ typedef int (*cmark_commonmark_escape_func) (cmark_syntax_extension *extension,
                                               int c);
 
 typedef void (*cmark_html_render_func) (cmark_syntax_extension *extension,
-                                        cmark_html_renderer *renderer,
+                                        struct cmark_html_renderer *renderer,
                                         cmark_node *node,
                                         cmark_event_type ev_type,
                                         int options);
@@ -271,6 +271,9 @@ cmark_syntax_extension *cmark_syntax_extension_new (const char *name);
 CMARK_EXPORT
 cmark_node_type cmark_syntax_extension_add_node(int is_inline);
 
+CMARK_EXPORT
+void cmark_syntax_extension_set_emphasis(cmark_syntax_extension *extension, int emphasis);
+
 /** See the documentation for 'cmark_syntax_extension'
  */
 CMARK_EXPORT
@@ -325,6 +328,12 @@ CMARK_EXPORT
 void cmark_syntax_extension_set_commonmark_render_func(cmark_syntax_extension *extension,
                                                        cmark_common_render_func func);
 
+/** See the documentation for 'cmark_syntax_extension'
+ */
+CMARK_EXPORT
+void cmark_syntax_extension_set_plaintext_render_func(cmark_syntax_extension *extension,
+                                                      cmark_common_render_func func);
+
 /** See the documentation for 'cmark_syntax_extension'
  */
 CMARK_EXPORT
@@ -362,6 +371,11 @@ void cmark_syntax_extension_set_private(cmark_syntax_extension *extension,
                                         void *priv,
                                         cmark_free_func free_func);
 
+/** See the documentation for 'cmark_syntax_extension'
+ */
+CMARK_EXPORT
+void *cmark_syntax_extension_get_private(cmark_syntax_extension *extension);
+
 /** See the documentation for 'cmark_syntax_extension'
  */
 CMARK_EXPORT
@@ -602,7 +616,7 @@ void cmark_inline_parser_set_offset(cmark_inline_parser *parser, int offset);
  * Use cmark_inline_parser_get_offset to get our current position in the chunk.
  */
 CMARK_EXPORT
-cmark_chunk *cmark_inline_parser_get_chunk(cmark_inline_parser *parser);
+struct cmark_chunk *cmark_inline_parser_get_chunk(cmark_inline_parser *parser);
 
 /** Returns 1 if the inline parser is currently in a bracket; pass 1 for 'image'
  * if you want to know about an image-type bracket, 0 for link-type. */
@@ -657,6 +671,12 @@ void cmark_inline_parser_remove_delimiter(cmark_inline_parser *parser, delimiter
 CMARK_EXPORT
 delimiter *cmark_inline_parser_get_last_delimiter(cmark_inline_parser *parser);
 
+CMARK_EXPORT
+int cmark_inline_parser_get_line(cmark_inline_parser *parser);
+
+CMARK_EXPORT
+int cmark_inline_parser_get_column(cmark_inline_parser *parser);
+
 /** Convenience function to scan a given delimiter.
  *
  * 'left_flanking' and 'right_flanking' will be set to true if they
@@ -681,11 +701,17 @@ int cmark_inline_parser_scan_delimiters(cmark_inline_parser *parser,
                                   int *punct_after);
 
 CMARK_EXPORT
-void cmark_manage_extensions_special_characters(cmark_parser *parser, bool add);
+void cmark_manage_extensions_special_characters(cmark_parser *parser, int add);
 
 CMARK_EXPORT
 cmark_llist *cmark_parser_get_syntax_extensions(cmark_parser *parser);
 
+CMARK_EXPORT
+void cmark_arena_push(void);
+
+CMARK_EXPORT
+int cmark_arena_pop(void);
+
 #ifdef __cplusplus
 }
 #endif
