@@ -41,6 +41,7 @@ void print_usage() {
   printf("  --smart          Use smart punctuation\n");
   printf("  --validate-utf8  Replace UTF-8 invalid sequences with U+FFFD\n");
   printf("  --github-pre-lang Use GitHub-style <pre lang> for code blocks\n");
+  printf("  --footnotes      Parse footnotes\n");
   printf("  --extension, -e EXTENSION_NAME Specify an extension name to use\n");
   printf("  --list-extensions              List available extensions and quit\n");
   printf("  --help, -h       Print usage information\n");
@@ -138,6 +139,8 @@ int main(int argc, char *argv[]) {
       options |= CMARK_OPT_SMART;
     } else if (strcmp(argv[i], "--github-pre-lang") == 0) {
       options |= CMARK_OPT_GITHUB_PRE_LANG;
+    } else if (strcmp(argv[i], "--footnotes") == 0) {
+      options |= CMARK_OPT_FOOTNOTES;
     } else if (strcmp(argv[i], "--safe") == 0) {
       options |= CMARK_OPT_SAFE;
     } else if (strcmp(argv[i], "--validate-utf8") == 0) {
