@@ -1,3 +1,6 @@
+#ifndef CMARK_CONFIG_H
+#define CMARK_CONFIG_H
+
 #define HAVE_STDBOOL_H
 
 #ifdef HAVE_STDBOOL_H
@@ -25,3 +28,5 @@
     #define CMARK_INLINE inline
   #endif
 #endif
+
+#endif
